@@ -42,6 +42,8 @@ class _LlamaModel:
 
         self._llama_free_model = llama_cpp._lib.llama_free_model  # type: ignore
 
+        self.model = None
+
         if not os.path.exists(path_model):
             raise ValueError(f"Model path does not exist: {path_model}")
 
@@ -248,6 +250,7 @@ class _LlamaContext:
         self.verbose = verbose
 
         self._llama_free = llama_cpp._lib.llama_free  # type: ignore
+        self.ctx = None
 
         assert self.model.model is not None
 
@@ -497,6 +500,7 @@ class _LlamaBatch:
 
         self._llama_batch_free = llama_cpp._lib.llama_batch_free  # type: ignore
 
+        self.batch = None
         self.batch = llama_cpp.llama_batch_init(
             self.n_tokens, self.embd, self.n_seq_max
         )
@@ -506,6 +510,14 @@ class _LlamaBatch:
             self._llama_batch_free(self.batch)
             self.batch = None
 
+    def n_tokens(self) -> int:
+        assert self.batch is not None
+        return self.batch.n_tokens
+
+    def reset(self):
+        assert self.batch is not None
+        self.batch.n_tokens = 0
+
     def set_batch(self, batch: Sequence[int], n_past: int, logits_all: bool):
         assert self.batch is not None
         n_tokens = len(batch)
@@ -518,6 +530,20 @@ class _LlamaBatch:
             self.batch.logits[i] = logits_all
         self.batch.logits[n_tokens - 1] = True
 
+    def add_sequence(self, batch: Sequence[int], seq_id: int, logits_all: bool):
+        assert self.batch is not None
+        n_tokens = len(batch)
+        n_tokens0 = self.batch.n_tokens
+        self.batch.n_tokens += n_tokens
+        for i in range(n_tokens):
+            j = n_tokens0 + i
+            self.batch.token[j] = batch[i]
+            self.batch.pos[j] = i
+            self.batch.seq_id[j][0] = seq_id
+            self.batch.n_seq_id[j] = 1
+            self.batch.logits[j] = logits_all
+        self.batch.logits[n_tokens - 1] = True
+
 
 class _LlamaTokenDataArray:
     def __init__(self, *, n_vocab: int):
